@@ -104,7 +104,6 @@ mod tests_has_duplicated_trailers {
 
     use std::option::Option::None;
 
-    use indoc::indoc;
     use miette::{GraphicalReportHandler, GraphicalTheme, Report};
     use mit_commit::CommitMessage;
 
@@ -114,13 +113,10 @@ mod tests_has_duplicated_trailers {
     #[test]
     fn commit_without_trailers() {
         test_lint_duplicated_trailers(
-            indoc!(
-                "
-                An example commit
+            "An example commit
 
-                This is an example commit without any duplicate trailers
-                "
-            )
+This is an example commit without any duplicate trailers
+"
             .into(),
             &None,
         );
@@ -128,18 +124,15 @@ mod tests_has_duplicated_trailers {
 
     #[test]
     fn two_duplicates() {
-        let message = indoc!(
-            "
-            An example commit
+        let message = "An example commit
 
-            This is an example commit without any duplicate trailers
+This is an example commit without any duplicate trailers
 
-            Signed-off-by: Billie Thompson <email@example.com>
-            Signed-off-by: Billie Thompson <email@example.com>
-            Co-authored-by: Billie Thompson <email@example.com>
-            Co-authored-by: Billie Thompson <email@example.com>
-            "
-        );
+Signed-off-by: Billie Thompson <email@example.com>
+Signed-off-by: Billie Thompson <email@example.com>
+Co-authored-by: Billie Thompson <email@example.com>
+Co-authored-by: Billie Thompson <email@example.com>
+";
         test_lint_duplicated_trailers(
             message.into(),
             &Some(Problem::new(
@@ -169,16 +162,13 @@ mod tests_has_duplicated_trailers {
 
     #[test]
     fn signed_off_by() {
-        let message = indoc!(
-            "
-                An example commit
+        let message = "An example commit
 
-                This is an example commit without any duplicate trailers
+This is an example commit without any duplicate trailers
 
-                Signed-off-by: Billie Thompson <email@example.com>
-                Signed-off-by: Billie Thompson <email@example.com>
-                "
-        );
+Signed-off-by: Billie Thompson <email@example.com>
+Signed-off-by: Billie Thompson <email@example.com>
+";
         test_lint_duplicated_trailers(
             message.into(),
             &Some(Problem::new(
@@ -197,16 +187,13 @@ mod tests_has_duplicated_trailers {
 
     #[test]
     fn co_authored_by() {
-        let message = indoc!(
-            "
-                An example commit
+        let message = "An example commit
 
-                This is an example commit without any duplicate trailers
+This is an example commit without any duplicate trailers
 
-                Co-authored-by: Billie Thompson <email@example.com>
-                Co-authored-by: Billie Thompson <email@example.com>
-                "
-        );
+Co-authored-by: Billie Thompson <email@example.com>
+Co-authored-by: Billie Thompson <email@example.com>
+";
         test_lint_duplicated_trailers(
             message.into(),
             &Some(Problem::new(
@@ -225,16 +212,13 @@ mod tests_has_duplicated_trailers {
 
     #[test]
     fn relates_to() {
-        let message = indoc!(
-            "
-                An example commit
+        let message = "An example commit
 
-                This is an example commit without any duplicate trailers
+This is an example commit without any duplicate trailers
 
-                Relates-to: #315
-                Relates-to: #315
-                "
-        );
+Relates-to: #315
+Relates-to: #315
+";
         test_lint_duplicated_trailers(
             message.into(),
             &Some(Problem::new(
@@ -254,39 +238,36 @@ mod tests_has_duplicated_trailers {
     #[test]
     fn trailer_like_duplicates_in_the_scissors_section() {
         test_lint_duplicated_trailers(
-            indoc!(
-                "
-                Move to specdown
-                # Bitte geben Sie eine Commit-Beschreibung fur Ihre Anderungen ein. Zeilen,
-                # die mit '#' beginnen, werden ignoriert, und eine leere Beschreibung
+            "Move to specdown
+# Bitte geben Sie eine Commit-Beschreibung fur Ihre Anderungen ein. Zeilen,
+# die mit '#' beginnen, werden ignoriert, und eine leere Beschreibung
 
-                # ------------------------ >8 ------------------------
-                # Andern oder entfernen Sie nicht die obige Zeile.
-                # Alles unterhalb von ihr wird ignoriert.
-                diff --git a/Makefile b/Makefile
-                index 0d3fc98..38a2784 100644
-                --- a/Makefile
-                +++ b/Makefile
-                +
-                 This is a commit message that has trailers and is invalid
+# ------------------------ >8 ------------------------
+# Andern oder entfernen Sie nicht die obige Zeile.
+# Alles unterhalb von ihr wird ignoriert.
+diff --git a/Makefile b/Makefile
+index 0d3fc98..38a2784 100644
+--- a/Makefile
++++ b/Makefile
++
+ This is a commit message that has trailers and is invalid
 
-                -Signed-off-by: Someone Else <someone@example.com>
-                -Signed-off-by: Someone Else <someone@example.com>
-                 Co-authored-by: Billie Thompson <billie@example.com>
-                 Co-authored-by: Billie Thompson <billie@example.com>
-                +Signed-off-by: Someone Else <someone@example.com>
-                +Signed-off-by: Someone Else <someone@example.com>
+-Signed-off-by: Someone Else <someone@example.com>
+-Signed-off-by: Someone Else <someone@example.com>
+ Co-authored-by: Billie Thompson <billie@example.com>
+ Co-authored-by: Billie Thompson <billie@example.com>
++Signed-off-by: Someone Else <someone@example.com>
++Signed-off-by: Someone Else <someone@example.com>
 
 
-                 ---
-                @@ -82,6 +82,7 @@ Co-authored-by: Billie Thompson <billie@example.com>
-                 Your commit message has duplicated trailers
+ ---
+@@ -82,6 +82,7 @@ Co-authored-by: Billie Thompson <billie@example.com>
+ Your commit message has duplicated trailers
 
-                 You can fix this by deleting the duplicated \"Signed-off-by\", \"Co-authored-by\" \
-                 fields
-                +
-                "
-            )
+ You can fix this by deleting the duplicated \"Signed-off-by\", \"Co-authored-by\" \
+ fields
++
+"
             .into(),
             &None,
         );
@@ -295,16 +276,13 @@ mod tests_has_duplicated_trailers {
     #[test]
     fn other_trailers() {
         test_lint_duplicated_trailers(
-            indoc!(
-                "
-                An example commit
+            "An example commit
 
-                This is an example commit without any duplicate trailers
+This is an example commit without any duplicate trailers
 
-                Anything: Billie Thompson <email@example.com>
-                Anything: Billie Thompson <email@example.com>
-                "
-            )
+Anything: Billie Thompson <email@example.com>
+Anything: Billie Thompson <email@example.com>
+"
             .into(),
             &None,
         );
@@ -321,43 +299,37 @@ mod tests_has_duplicated_trailers {
 
     #[test]
     fn formatting() {
-        let message = indoc!(
-            "
-            An example commit
+        let message = "An example commit
 
-            This is an example commit without any duplicate trailers
+This is an example commit without any duplicate trailers
 
-            Signed-off-by: Billie Thompson <email@example.com>
-            Signed-off-by: Billie Thompson <email@example.com>
-            Co-authored-by: Billie Thompson <email@example.com>
-            Co-authored-by: Billie Thompson <email@example.com>
-            "
-        );
+Signed-off-by: Billie Thompson <email@example.com>
+Signed-off-by: Billie Thompson <email@example.com>
+Co-authored-by: Billie Thompson <email@example.com>
+Co-authored-by: Billie Thompson <email@example.com>
+";
         let problem = lint(&CommitMessage::from(message.to_string()));
         let actual = fmt_report(&Report::new(problem.unwrap()));
-        let expected = indoc!(
-            "
-            DuplicatedTrailers
-            
-              \u{d7} Your commit message has duplicated trailers
-               \u{256d}\u{2500}[5:1]
-             5 \u{2502} Signed-off-by: Billie Thompson <email@example.com>
-             6 \u{2502} Signed-off-by: Billie Thompson <email@example.com>
-               \u{b7} \u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{252c}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}
-               \u{b7}                          \u{2570}\u{2500}\u{2500} Duplicated `Signed-off-by`
-             7 \u{2502} Co-authored-by: Billie Thompson <email@example.com>
-             8 \u{2502} Co-authored-by: Billie Thompson <email@example.com>
-               \u{b7} \u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{252c}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}
-               \u{b7}                          \u{2570}\u{2500}\u{2500} Duplicated `Co-authored-by`
-               \u{2570}\u{2500}\u{2500}\u{2500}\u{2500}
-              help: These are normally added accidentally when you're rebasing or
-                    amending to a commit, sometimes in the text editor, but often by
-                    git hooks.
-                    
-                    You can fix this by deleting the duplicated \"Co-authored-by\",
-                    \"Signed-off-by\" fields
-            "
-        )
+        let expected = "DuplicatedTrailers
+
+  \u{d7} Your commit message has duplicated trailers
+   \u{256d}\u{2500}[5:1]
+ 5 \u{2502} Signed-off-by: Billie Thompson <email@example.com>
+ 6 \u{2502} Signed-off-by: Billie Thompson <email@example.com>
+   \u{b7} \u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{252c}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}
+   \u{b7}                          \u{2570}\u{2500}\u{2500} Duplicated `Signed-off-by`
+ 7 \u{2502} Co-authored-by: Billie Thompson <email@example.com>
+ 8 \u{2502} Co-authored-by: Billie Thompson <email@example.com>
+   \u{b7} \u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{252c}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}
+   \u{b7}                          \u{2570}\u{2500}\u{2500} Duplicated `Co-authored-by`
+   \u{2570}\u{2500}\u{2500}\u{2500}\u{2500}
+  help: These are normally added accidentally when you're rebasing or
+        amending to a commit, sometimes in the text editor, but often by
+        git hooks.
+        
+        You can fix this by deleting the duplicated \"Co-authored-by\",
+        \"Signed-off-by\" fields
+"
         .to_string();
         assert_eq!(
             actual, expected,
