@@ -61,30 +61,22 @@ pub(crate) fn lint(commit_message: &CommitMessage) -> Option<Problem> {
 mod tests {
     #![allow(clippy::wildcard_imports)]
 
-    use indoc::indoc;
-
     use super::*;
     use crate::model::{Code, Problem};
 
     #[test]
     fn subject_does_not_end_with_period() {
         run_test(
-            indoc!(
-                "
-                Subject Line
-                "
-            ),
+            "Subject Line
+",
             &None,
         );
     }
 
     #[test]
     fn subject_ends_with_period() {
-        let message = indoc!(
-            "
-            Subject Line.
-            "
-        );
+        let message = "Subject Line.
+";
         run_test(
             message,
             &Some(Problem::new(
@@ -136,35 +128,29 @@ mod tests {
 
     #[test]
     fn formatting() {
-        let message = indoc!(
-            "
-            An example commit... 
+        let message = "An example commit... 
 
-            This is an example commit
-            "
-        );
+This is an example commit
+";
         let problem = lint(&CommitMessage::from(message.to_string()));
         let actual = fmt_report(&Report::new(problem.unwrap()));
-        let expected = indoc!(
-            "
-            SubjectEndsWithPeriod
-            
-              \u{d7} Your commit message ends with a period
-               \u{256d}\u{2500}[1:1]
-             1 \u{2502} ... 
-               \u{b7} \u{2500}\u{252c}\u{2500}
-               \u{b7}  \u{2570}\u{2500}\u{2500} Unneeded period
-             2 \u{2502} 
-               \u{2570}\u{2500}\u{2500}\u{2500}\u{2500}
-              help: It's important to keep your commits short, because we only have a
-                    limited number of characters to use (72) before the subject line
-                    is truncated. Full stops aren't normally in subject lines, and take
-                    up an extra character, so we shouldn't use them in commit message
-                    subjects.
-                    
-                    You can fix this by removing the period
-            "
-        )
+        let expected = "SubjectEndsWithPeriod
+
+  \u{d7} Your commit message ends with a period
+   \u{256d}\u{2500}[1:1]
+ 1 \u{2502} ... 
+   \u{b7} \u{2500}\u{252c}\u{2500}
+   \u{b7}  \u{2570}\u{2500}\u{2500} Unneeded period
+ 2 \u{2502} 
+   \u{2570}\u{2500}\u{2500}\u{2500}\u{2500}
+  help: It's important to keep your commits short, because we only have a
+        limited number of characters to use (72) before the subject line
+        is truncated. Full stops aren't normally in subject lines, and take
+        up an extra character, so we shouldn't use them in commit message
+        subjects.
+        
+        You can fix this by removing the period
+"
         .to_string();
         assert_eq!(
             actual, expected,
